pm4py.algo.evaluation.earth\_mover\_distance package
====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.evaluation.earth_mover_distance.variants

Submodules
----------

pm4py.algo.evaluation.earth\_mover\_distance.algorithm module
-------------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.earth_mover_distance.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.earth\_mover\_distance.evaluator module
-------------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.earth_mover_distance.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation.earth_mover_distance
   :members:
   :undoc-members:
   :show-inheritance:
